Welcome to elasticluster’s documentation! — elasticluster 1.0 documentation

### Navigation

- index
- next |
- elasticluster 1.0 documentation »

# Welcome to elasticluster’s documentation!

## Introduction

elasticluster aims to provide a user-friendly command line tool to create, manage and setup computing clusters hosted on cloud infrastructures (like Amazon’s Elastic Compute Cloud EC2) or a private OpenStack cloud). Its main goal is to get your own private cluster up and running with just a few commands; a YouTube video demoes the basic features of elasticluster.

This project is an effort of the Grid Computing Competence Center at the University of Zurich, licensed under the GNU General Public License version 3.

## Features

elasticluster is in active development, but the following features at the current state:

- Simple configuration file to define cluster templates

- Can start and manage multiple independent clusters at the same time

- Automated cluster setup:
    - use Debian GNU/Linux, Ubuntu, or CentOS as a base operating system
    - choose SLURM, Grid Engine or Torque/PBS as a batch-queueing system
    - add useful tools like Ganglia for monitoring...
    - ...or anything that you can install with an Ansible playbook!

- Grow and shrink a running cluster

elasticluster is currently in active development: please use the GitHub issue tracker to file enhancement requests and ideas

## Table of Contents

- Installation of elasticluster
  - Installing from PyPI
  - Installing from github
- Configuration of elasticluster
  - Syntax of the configuration file
- Usage
- Available playbooks for elasticluster
- How to customize elasticluster

## Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- elasticluster 1.0 documentation »